@@ -7,230 +7,230 @@ import vdf
 import re
 
 
-munitionCrate = {
-    "82": 5734,
-    "83": 5735,
-    "84": 5742,
-    "85": 5752,
-    "90": 5781,
-    "91": 5802,
-    "92": 5803,
-    "103": 5859
-}
+# munitionCrate = {
+#     "82": 5734,
+#     "83": 5735,
+#     "84": 5742,
+#     "85": 5752,
+#     "90": 5781,
+#     "91": 5802,
+#     "92": 5803,
+#     "103": 5859
+# }
 
 
-pistolSkins = {
-	"0": 15013,
-	"18": 15018,
-	"35": 15035,
-	"41": 15041,
-	"46": 15046,
-	"56": 15056,
-	"61": 15061,
-	"63": 15060,
-	"69": 15100,
-	"70": 15101,
-	"74": 15102,
-	"78": 15126,
-	"81": 15148
-}
+# pistolSkins = {
+# 	"0": 15013,
+# 	"18": 15018,
+# 	"35": 15035,
+# 	"41": 15041,
+# 	"46": 15046,
+# 	"56": 15056,
+# 	"61": 15061,
+# 	"63": 15060,
+# 	"69": 15100,
+# 	"70": 15101,
+# 	"74": 15102,
+# 	"78": 15126,
+# 	"81": 15148
+# }
 
 
-rocketLauncherSkins = {
-	"1": 15014,
-	"6": 15006,
-	"28": 15028,
-	"43": 15043,
-	"52": 15052,
-	"57": 15057,
-	"60": 15081,
-	"69": 15104,
-	"70": 15105,
-	"76": 15129,
-	"79": 15130,
-	"80": 15150
-}
+# rocketLauncherSkins = {
+# 	"1": 15014,
+# 	"6": 15006,
+# 	"28": 15028,
+# 	"43": 15043,
+# 	"52": 15052,
+# 	"57": 15057,
+# 	"60": 15081,
+# 	"69": 15104,
+# 	"70": 15105,
+# 	"76": 15129,
+# 	"79": 15130,
+# 	"80": 15150
+# }
 
 
-medicgunSkins = {
-	"2": 15010,
-	"5": 15008,
-	"25": 15025,
-	"39": 15039,
-	"50": 15050,
-	"65": 15078,
-	"72": 15097,
-	"76": 15120,
-	"78": 15121,
-	"79": 15122,
-	"81": 15145,
-	"83": 15146
-}
+# medicgunSkins = {
+# 	"2": 15010,
+# 	"5": 15008,
+# 	"25": 15025,
+# 	"39": 15039,
+# 	"50": 15050,
+# 	"65": 15078,
+# 	"72": 15097,
+# 	"76": 15120,
+# 	"78": 15121,
+# 	"79": 15122,
+# 	"81": 15145,
+# 	"83": 15146
+# }
 
 
-revolverSkins = {
-	"3": 15011,
-	"27": 15027,
-	"42": 15042,
-	"51": 15051,
-	"63": 15064,
-	"64": 15062,
-	"65": 15063,
-	"72": 15103,
-	"76": 15127,
-	"77": 15128,
-	"81": 15149
-}
+# revolverSkins = {
+# 	"3": 15011,
+# 	"27": 15027,
+# 	"42": 15042,
+# 	"51": 15051,
+# 	"63": 15064,
+# 	"64": 15062,
+# 	"65": 15063,
+# 	"72": 15103,
+# 	"76": 15127,
+# 	"77": 15128,
+# 	"81": 15149
+# }
 
 
-stickybombSkins = {
-	"4": 15012,
-	"8": 15009,
-	"24": 15024,
-	"38": 15038,
-	"45": 15045,
-	"48": 15048,
-	"60": 15082,
-	"62": 15083,
-	"63": 15084,
-	"68": 15113,
-	"76": 15137,
-	"78": 15138,
-	"81": 15155
-}
+# stickybombSkins = {
+# 	"4": 15012,
+# 	"8": 15009,
+# 	"24": 15024,
+# 	"38": 15038,
+# 	"45": 15045,
+# 	"48": 15048,
+# 	"60": 15082,
+# 	"62": 15083,
+# 	"63": 15084,
+# 	"68": 15113,
+# 	"76": 15137,
+# 	"78": 15138,
+# 	"81": 15155
+# }
 
 
-sniperRifleSkins = {
-	"7": 15007,
-	"14": 15000,
-	"19": 15019,
-	"23": 15023,
-	"33": 15033,
-	"59": 15059,
-	"62": 15070,
-	"64": 15071,
-	"65": 15072,
-	"76": 15135,
-	"66": 15111,
-	"67": 15112,
-	"78": 15136,
-	"82": 15154
-}
+# sniperRifleSkins = {
+# 	"7": 15007,
+# 	"14": 15000,
+# 	"19": 15019,
+# 	"23": 15023,
+# 	"33": 15033,
+# 	"59": 15059,
+# 	"62": 15070,
+# 	"64": 15071,
+# 	"65": 15072,
+# 	"76": 15135,
+# 	"66": 15111,
+# 	"67": 15112,
+# 	"78": 15136,
+# 	"82": 15154
+# }
 
 
-flameThrowerSkins = {
-	"9": 15005,
-	"17": 15017,
-	"30": 15030,
-	"34": 15034,
-	"49": 15049,
-	"54": 15054,
-	"60": 15066,
-	"61": 15068,
-	"62": 15067,
-	"66": 15089,
-	"67": 15090,
-	"76": 15115,
-	"80": 15141
-}
+# flameThrowerSkins = {
+# 	"9": 15005,
+# 	"17": 15017,
+# 	"30": 15030,
+# 	"34": 15034,
+# 	"49": 15049,
+# 	"54": 15054,
+# 	"60": 15066,
+# 	"61": 15068,
+# 	"62": 15067,
+# 	"66": 15089,
+# 	"67": 15090,
+# 	"76": 15115,
+# 	"80": 15141
+# }
 
 
-minigunSkins = {
-	"10": 15004,
-	"20": 15020,
-	"26": 15026,
-	"31": 15031,
-	"40": 15040,
-	"55": 15055,
-	"61": 15088,
-	"62": 15087,
-	"63": 15086,
-	"70": 15098,
-	"73": 15099,
-	"76": 15123,
-	"77": 15125,
-	"78": 15124,
-	"84": 15147
-}
+# minigunSkins = {
+# 	"10": 15004,
+# 	"20": 15020,
+# 	"26": 15026,
+# 	"31": 15031,
+# 	"40": 15040,
+# 	"55": 15055,
+# 	"61": 15088,
+# 	"62": 15087,
+# 	"63": 15086,
+# 	"70": 15098,
+# 	"73": 15099,
+# 	"76": 15123,
+# 	"77": 15125,
+# 	"78": 15124,
+# 	"84": 15147
+# }
 
 
-scattergunSkins = {
-	"11": 15002,
-	"15": 15015,
-	"21": 15021,
-	"29": 15029,
-	"36": 15036,
-	"53": 15053,
-	"61": 15069,
-	"63": 15065,
-	"69": 15106,
-	"72": 15107,
-	"74": 15108,
-	"76": 15131,
-	"83": 15157,
-	"85": 15151
-}
+# scattergunSkins = {
+# 	"11": 15002,
+# 	"15": 15015,
+# 	"21": 15021,
+# 	"29": 15029,
+# 	"36": 15036,
+# 	"53": 15053,
+# 	"61": 15069,
+# 	"63": 15065,
+# 	"69": 15106,
+# 	"72": 15107,
+# 	"74": 15108,
+# 	"76": 15131,
+# 	"83": 15157,
+# 	"85": 15151
+# }
 
 
-shotgunSkins = {
-	"12": 15003,
-	"16": 15016,
-	"44": 15044,
-	"47": 15047,
-	"60": 15085,
-	"72": 15109,
-	"76": 15132,
-	"78": 15133,
-	"86": 15152
-}
+# shotgunSkins = {
+# 	"12": 15003,
+# 	"16": 15016,
+# 	"44": 15044,
+# 	"47": 15047,
+# 	"60": 15085,
+# 	"72": 15109,
+# 	"76": 15132,
+# 	"78": 15133,
+# 	"86": 15152
+# }
 
 
-smgSkins = {
-	"13": 15001,
-	"22": 15022,
-	"32": 15032,
-	"37": 15037,
-	"58": 15058,
-	"65": 15076,
-	"69": 15110,
-	"79": 15134,
-	"81": 15153
-}
+# smgSkins = {
+# 	"13": 15001,
+# 	"22": 15022,
+# 	"32": 15032,
+# 	"37": 15037,
+# 	"58": 15058,
+# 	"65": 15076,
+# 	"69": 15110,
+# 	"79": 15134,
+# 	"81": 15153
+# }
 
 
-wrenchSkins = {
-	"60": 15074,
-	"61": 15073,
-	"64": 15075,
-	"75": 15114,
-	"77": 15140,
-	"78": 15139,
-	"82": 15156
-}
+# wrenchSkins = {
+# 	"60": 15074,
+# 	"61": 15073,
+# 	"64": 15075,
+# 	"75": 15114,
+# 	"77": 15140,
+# 	"78": 15139,
+# 	"82": 15156
+# }
 
 
-grenadeLauncherSkins = {
-	"60": 15077,
-	"63": 15079,
-	"67": 15091,
-	"68": 15092,
-	"76": 15116,
-	"77": 15117,
-	"80": 15142,
-	"84": 15158
-}
+# grenadeLauncherSkins = {
+# 	"60": 15077,
+# 	"63": 15079,
+# 	"67": 15091,
+# 	"68": 15092,
+# 	"76": 15116,
+# 	"77": 15117,
+# 	"80": 15142,
+# 	"84": 15158
+# }
 
 
-knifeSkins = {
-	"64": 15080,
-	"69": 15094,
-	"70": 15095,
-	"71": 15096,
-	"77": 15119,
-	"78": 15118,
-	"81": 15143,
-	"82": 15144
-}
+# knifeSkins = {
+# 	"64": 15080,
+# 	"69": 15094,
+# 	"70": 15095,
+# 	"71": 15096,
+# 	"77": 15119,
+# 	"78": 15118,
+# 	"81": 15143,
+# 	"82": 15144
+# }
 
 
 exclusiveGenuine = {
@@ -290,6 +290,8 @@ class Schema:
         self.raw = data["raw"] or None
         self.time = data["time"] or time.time()
         self.crateSeriesList = self.getCrateSeriesList()
+        self.munitionCratesList = self.getMunitionCratesList()
+        self.getWeaponSkinsList = self.getWeaponSkinsList()
 
 
     def getItemByNameWithThe(self, name):
@@ -330,7 +332,7 @@ class Schema:
             if not schemaItem: 
                 return item
             item["defindex"] = schemaItem["defindex"]
-            item["quality"] = item["quality"] or schemaItem["quality"] # default quality
+            item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
             return item
 
         wears = {
@@ -471,13 +473,30 @@ class Schema:
             if effect == "accursed" and "accursed apparition" in name:
                 # Accursed Apparition never be an unusual
                 continue
-            if effect == "hot" and not item.get("wear"):
-                continue
-            if effect == "hot" and "hot " not in name and ("shotgun" in name or "plaid potshotter" in name or "shot to hell" in name):
-                continue
+            if effect == "hot": 
+                # shotgun # shot to hell
+                # plaid potshotter # shot in the dark
+                if not item.get("wear"):
+                    continue
+                elif "hot " not in name and ("shotgun" in name or "shot " in name or "plaid potshotter" in name):
+                    # Shotgun
+                    # Strange Shotgun
+                    # Plaid Potshotter Mk.II Shotgun (Factory New)
+                    # Shot to Hell Sniper Rifle (Factory New)
+                    # Shot in the Dark Sniper Rifle (Factory New)
+                    # Strange Plaid Potshotter Mk.II Shotgun (Factory New)
+                    # Strange Shot to Hell Sniper Rifle (Factory New)
+                    # Strange Shot in the Dark Sniper Rifle (Factory New)
+                    # Strange Cool Shot to Hell Sniper Rifle (Factory New)
+                    # Strange Shot in the Dark Sniper Rifle (Factory New)
+                    continue
+                elif name.startswith("hot "):
+                    pass
+                else:
+                    continue
             if effect == "cool" and not item.get("wear"):
                 continue
-            if effect in name and "shot in the dark" not in name:
+            if effect in name:
                 name = name.replace(effect, "", 1).strip()
                 item["effect"] = effects[effect]
                 if  item["effect"] == 4:
@@ -515,47 +534,47 @@ class Schema:
                     # Special Skins, but still need to filter because not everything is special
                     # TODO: Investigate whether this also the reason we have two Strange variants for skins?
                     if 'pistol' in name:
-                        if str(item['paintkit']) in pistolSkins:
-                            item['defindex'] = pistolSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["pistolSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["pistolSkins"][str(item['paintkit'])]
                     elif 'rocket launcher' in name:
-                        if str(item['paintkit']) in rocketLauncherSkins:
-                            item['defindex'] = rocketLauncherSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["rocketLauncherSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["rocketLauncherSkins"][str(item['paintkit'])]
                     elif 'medi gun' in name:
-                        if str(item['paintkit']) in medicgunSkins:
-                            item['defindex'] = medicgunSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["medicgunSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["medicgunSkins"][str(item['paintkit'])]
                     elif 'revolver' in name:
-                        if str(item['paintkit']) in revolverSkins:
-                            item['defindex'] = revolverSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["revolverSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["revolverSkins"][str(item['paintkit'])]
                     elif 'stickybomb launcher' in name:
-                        if str(item['paintkit']) in stickybombSkins:
-                            item['defindex'] = stickybombSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["stickybombSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["stickybombSkins"][str(item['paintkit'])]
                     elif 'sniper rifle' in name:
-                        if str(item['paintkit']) in sniperRifleSkins:
-                            item['defindex'] = sniperRifleSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["sniperRifleSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["sniperRifleSkins"][str(item['paintkit'])]
                     elif 'flame thrower' in name:
-                        if str(item['paintkit']) in flameThrowerSkins:
-                            item['defindex'] = flameThrowerSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["flameThrowerSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["flameThrowerSkins"][str(item['paintkit'])]
                     elif 'minigun' in name:
-                        if str(item['paintkit']) in minigunSkins:
-                            item['defindex'] = minigunSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["minigunSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["minigunSkins"][str(item['paintkit'])]
                     elif 'scattergun' in name:
-                        if str(item['paintkit']) in scattergunSkins:
-                            item['defindex'] = scattergunSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["scattergunSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["scattergunSkins"][str(item['paintkit'])]
                     elif 'shotgun' in name:
-                        if str(item['paintkit']) in shotgunSkins:
-                            item['defindex'] = shotgunSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["shotgunSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["shotgunSkins"][str(item['paintkit'])]
                     elif 'smg' in name:
-                        if str(item['paintkit']) in smgSkins:
-                            item['defindex'] = smgSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["smgSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["smgSkins"][str(item['paintkit'])]
                     elif 'grenade launcher' in name:
-                        if str(item['paintkit']) in grenadeLauncherSkins:
-                            item['defindex'] = grenadeLauncherSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["grenadeLauncherSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["grenadeLauncherSkins"][str(item['paintkit'])]
                     elif 'wrench' in name:
-                        if str(item['paintkit']) in wrenchSkins:
-                            item['defindex'] = wrenchSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["wrenchSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["wrenchSkins"][str(item['paintkit'])]
                     elif 'knife' in name:
-                        if str(item['paintkit']) in knifeSkins:
-                            item['defindex'] = knifeSkins[str(item['paintkit'])]
+                        if str(item['paintkit']) in self.getWeaponSkinsList["knifeSkins"]:
+                            item['defindex'] = self.getWeaponSkinsList["knifeSkins"][str(item['paintkit'])]
                 if oldDefindex != item["defindex"]: return item
 
         if "(paint: " in name:
@@ -653,12 +672,11 @@ class Schema:
                 schemaItem = self.getItemByItemName(name)
                 if not schemaItem: return item
                 item["target"] = schemaItem["defindex"]
-                item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
             if not item.get("quality"): item["quality"] = 6
 
         if item.get("defindex"): return item
 
-        if item.get("paintkit") and "war paint" in name:
+        if isinstance(item.get("paintkit"), int) and "war paint" in name:
             name = f"Paintkit {item['paintkit']}"
             if not item.get("quality"): item["quality"] = 15
             items = schema["items"]
@@ -669,13 +687,19 @@ class Schema:
 
         else:
             name = name.replace(" series ", "").replace(" series#", " #")
-            if name.startswith('mann co. supply crate #'):
+            if "salvaged mann co. supply crate #" in name:
+                item["crateseries"] = int(name[32:])
+                item["defindex"] = 5068
+                item["quality"] = 6
+                return item
+
+            elif "mann co. supply crate #" in name:
                 crateseries = int(name[23:])
-                if crateseries in [1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75]:
+                if crateseries in {1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75}:
                     item["defindex"] = 5022
-                elif crateseries in [2, 4, 8, 11, 14, 17, 20, 24, 27, 32, 37, 42, 44, 49, 56, 71, 76]:
+                elif crateseries in {2, 4, 8, 11, 14, 17, 20, 24, 27, 32, 37, 42, 44, 49, 56, 71, 76}:
                     item["defindex"] = 5041
-                elif crateseries in [5, 9, 10, 15, 16, 21, 25, 28, 29, 33, 38, 41, 45, 55, 59, 77]:
+                elif crateseries in {5, 9, 10, 15, 16, 21, 25, 28, 29, 33, 38, 41, 45, 55, 59, 77}:
                     item["defindex"] = 5045
                 item["crateseries"] = crateseries
                 item["quality"] = 6
@@ -683,17 +707,11 @@ class Schema:
 
             elif "mann co. supply munition #" in name:
                 crateseries = int(name[26:])
-                item["defindex"] = munitionCrate.get(crateseries)
+                item["defindex"] = self.munitionCratesList.get(str(crateseries))
                 item["crateseries"] = crateseries
                 item["quality"] = 6
                 return item
 
-            elif "salvaged mann co. supply crate #" in name:
-                item["crateseries"] = int(name[32:])
-                item["defindex"] = 5068
-                item["quality"] = 6
-                return item
-
             number = None
 
             if "#" in name:
@@ -953,7 +971,7 @@ class Schema:
     
     # Gets the name of partial sku for strange parts items
     def getStrangeParts(self):
-        partsToExclude = [
+        partsToExclude = {
             'Ubers',
             'Kill Assists',
             'Sentry Kills',
@@ -994,7 +1012,7 @@ class Schema:
             'Power Up Canteens Used',
             'Contract Points Earned',
             'Contract Points Contributed To Friends'
-        ]
+        }
 
         toObject = {}
 
@@ -1011,7 +1029,7 @@ class Schema:
 
     # Get an array of item objects for craftable weapons
     def getCraftableWeaponsSchema(self):
-        weaponsToExclude = [
+        weaponsToExclude = {
             # Exclude these weapons
             266, # Horseless Headless Horsemann's Headtaker
             452, # Three-Rune Blade
@@ -1032,7 +1050,7 @@ class Schema:
             1013, # Ham Shank
             1152, # Grappling Hook
             30474 # Nostromo Napalmer
-        ]
+        }
 
         craftableWeapons = []
         for item in self.raw["schema"]["items"]:
@@ -1043,7 +1061,7 @@ class Schema:
 
     # Get an array of SKU for craftable weapons by class used for crafting
     def getWeaponsForCraftingByClass(self, charClass):
-        if charClass not in ['Scout', 'Soldier', 'Pyro', 'Demoman', 'Heavy', 'Engineer', 'Medic', 'Sniper', 'Spy']:
+        if charClass not in {'Scout', 'Soldier', 'Pyro', 'Demoman', 'Heavy', 'Engineer', 'Medic', 'Sniper', 'Spy'}:
             raise Exception(f'Entered class "{charClass}" is not a valid character class.\nValid character classes (case sensitive): "Scout", "Soldier", "Pyro", "Demoman", "Heavy", "Engineer", "Medic", "Sniper", "Spy".')
         
         weapons = []
@@ -1102,7 +1120,7 @@ class Schema:
         if not schemaItem: return False
 
         # Items with default quality
-        if schemaItem["item_quality"] in [0, 3, 5, 11]:
+        if schemaItem["item_quality"] in {0, 3, 5, 11}:
             # default Normal (Stock items), Vintage (1156), Unusual (266, 267), and Strange (655) items
             if item.get("quality") != schemaItem["item_quality"]: return False
 
@@ -1140,8 +1158,8 @@ class Schema:
                 item["outputQuality"] is not None or
                 item["paint"] is not None
             )
-        if schemaItem["item_class"] == "supply_crate" and item.get("crateseries"):
-            if item["defindex"] not in [5739, 5760, 5737, 5738]:
+        if schemaItem["item_class"] == "supply_crate" and item.get("crateseries") is None:
+            if item["defindex"] not in {5739, 5760, 5737, 5738}:
                 # If not seriesless, return false
                 # Mann Co. Director's Cut Reel, Mann Co. Audition Reel, and Mann Co. Stockpile Crate
                 return False
@@ -1154,9 +1172,9 @@ class Schema:
             if schemaItem["item_class"] != "supply_crate":
                 # Not a crate or case
                 return False
-            elif (item["crateseries"] not in [1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75, 2, 4, 8, 11, 14, 17, 20, 24, 27,
+            elif (item["crateseries"] not in {1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75, 2, 4, 8, 11, 14, 17, 20, 24, 27,
                 32, 37, 42, 44, 49, 56, 71, 76, 5, 9, 10, 15, 16, 21, 25, 28, 29, 33, 38, 41, 45, 55, 59, 77, 30,
-                40, 50, 82, 83, 84, 85, 90, 91, 92, 103]):
+                40, 50, 82, 83, 84, 85, 90, 91, 92, 103}):
                 # if item["crateseries"] not included in the single defindex multiple series crate:
                 if item["crateseries"] not in [self.crateSeriesList[cratesSeries] for cratesSeries in self.crateSeriesList]:
                     # if item["crateseries"] is not included in the crateSeriesList, does not exist.
@@ -1164,11 +1182,11 @@ class Schema:
                 # Check for specific crates/cases
                 if item["crateseries"] != self.crateSeriesList[item["defindex"]]: return False
             elif not (
-                (item["crateseries"] in [1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75] and item["defindex"] == 5022) or
-                (item["crateseries"] in [2, 4, 8, 11, 14, 17, 20, 24, 27, 32, 37, 42, 44, 49, 56, 71, 76] and item["defindex"] == 5041) or
-                (item["crateseries"] in [5, 9, 10, 15, 16, 21, 25, 28, 29, 33, 38, 41, 45, 55, 59, 77] and item["defindex"] == 5045) or
-                (item["crateseries"] in [30, 40, 50] and item["defindex"] == 5068) or
-                (munitionCrate.get(item["crateseries"]) and item["defindex"] == munitionCrate.get(item["crateseries"]))):
+                (item["crateseries"] in {1, 3, 7, 12, 13, 18, 19, 23, 26, 31, 34, 39, 43, 47, 54, 57, 75} and item["defindex"] == 5022) or
+                (item["crateseries"] in {2, 4, 8, 11, 14, 17, 20, 24, 27, 32, 37, 42, 44, 49, 56, 71, 76} and item["defindex"] == 5041) or
+                (item["crateseries"] in {5, 9, 10, 15, 16, 21, 25, 28, 29, 33, 38, 41, 45, 55, 59, 77} and item["defindex"] == 5045) or
+                (item["crateseries"] in {30, 40, 50} and item["defindex"] == 5068) or
+                (self.munitionCratesList.get(str(item["crateseries"])) and item["defindex"] == self.munitionCratesList.get(str(item["crateseries"])))):
                 # if single defindex multiple series crate don't match, does not exist
                 return False
 
@@ -1176,7 +1194,7 @@ class Schema:
 
 
     # Gets the name of an item with specific attributes
-    def getName(self, item, proper=True):
+    def getName(self, item, proper=True, usePipeForSkin=False):
         schemaItem = self.getItemByDefindex(item["defindex"])
         if schemaItem is None: return None
 
@@ -1192,8 +1210,9 @@ class Schema:
 
         if ((item["quality"] != 6 and item["quality"] != 15 and item["quality"]  != 5) or
             (item["quality"]  == 5 and not item.get("effect")) or
+            (item["quality"] == 6 and item.get("quality2")) or
             schemaItem["item_quality"] == 5):
-            # If the quality is not Unique, Decorated, or Unusual, or if the quality is Unusual but it does not have an effect, or if the item can only be unusual, then add the quality
+            # If the quality is Unique (and is Elevated quality) or not Unique, Decorated, or Unusual, or if the quality is Unusual but it does not have an effect, or if the item can only be unusual, then add the quality
             name += self.getQualityById(item["quality"]) + " "
 
         if item.get("effect"): name += self.getEffectById(item["effect"]) + " "
@@ -1208,9 +1227,9 @@ class Schema:
 
         if item.get("output"): name += self.getItemByDefindex(item["output"])["item_name"] + " "
 
-        if item.get("australium") is True: name += "Australium"
+        if item.get("australium") is True: name += "Australium "
 
-        if item.get("paintkit") and type(item["paintkit"]) == int: name += self.getSkinById(item["paintkit"]) + " "
+        if item.get("paintkit") and type(item["paintkit"]) == int: name += self.getSkinById(item["paintkit"]) + (" " if usePipeForSkin is False else " | ")
 
         if proper is True and name == "" and schemaItem["proper_name"] is True: name = "The "
 
@@ -1234,11 +1253,94 @@ class Schema:
 
     # Gets name
     def getNameFromSku(self, sku):
-        if testSKU(sku) is True:
+        if self.testSKU(sku) is True:
             return self.getName(SKU.fromString(sku))
         else:
             return None
 
+    
+    # Check sku if it's valid or not
+    def testSKU(self, sku):
+        if bool(re.match(
+            "^(\d+);([0-9]|[1][0-5])(;((uncraftable)|(untrad(e)?able)|(australium)|(festive)|(strange)|((u|pk|td-|c|od-|oq-|p)\d+)|(w[1-5])|(kt-[1-3])|(n((100)|[1-9]\d?))))*?$", sku)):
+            return True
+
+    
+    # Gets munition crate list
+    def getMunitionCratesList(self):
+        munitionCratesList = {}
+        items = self.raw["schema"]["items"]
+        for item in items:
+            if item["item_name"] == "Mann Co. Supply Munition":
+                munitionCratesList.update({str(item["attributes"][0]["value"]): int(item["defindex"])})
+        return munitionCratesList
+
+
+    # Gets weapon skins list
+    def getWeaponSkinsList(self):
+        items = self.raw["items_game"]["items"]
+        pistolSkins = {}
+        rocketLauncherSkins = {}
+        medicgunSkins = {}
+        revolverSkins = {}
+        stickybombSkins = {}
+        sniperRifleSkins = {}
+        flameThrowerSkins = {}
+        minigunSkins = {}
+        scattergunSkins = {}
+        shotgunSkins = {}
+        smgSkins = {}
+        wrenchSkins = {}
+        grenadeLauncherSkins = {}
+        knifeSkins = {}
+        for item in items:
+            if items[item].get("prefab"):
+                if items[item]["prefab"] == "paintkit_weapon_pistol":
+                    pistolSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_rocketlauncher":
+                    rocketLauncherSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_medigun":
+                    medicgunSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_revolver":
+                    revolverSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_stickybomb_launcher":
+                    stickybombSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_sniperrifle":
+                    sniperRifleSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_flamethrower":
+                    flameThrowerSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_minigun":
+                    minigunSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_scattergun":
+                    scattergunSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_shotgun":
+                    shotgunSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_smg":
+                    smgSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_wrench":
+                    wrenchSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_grenadelauncher":
+                    grenadeLauncherSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+                elif items[item]["prefab"] == "paintkit_weapon_knife":
+                    knifeSkins.update({str(items[item]["static_attrs"]["paintkit_proto_def_index"]): int(item)})
+        weaponSkinsList = {
+            "pistolSkins": pistolSkins,
+            "rocketLauncherSkins": rocketLauncherSkins,
+            "medicgunSkins": medicgunSkins,
+            "revolverSkins": revolverSkins,
+            "stickybombSkins": stickybombSkins,
+            "sniperRifleSkins": sniperRifleSkins,
+            "flameThrowerSkins": flameThrowerSkins,
+            "minigunSkins": minigunSkins,
+            "scattergunSkins": scattergunSkins,
+            "shotgunSkins": shotgunSkins,
+            "smgSkins": smgSkins,
+            "wrenchSkins": wrenchSkins,
+            "grenadeLauncherSkins": grenadeLauncherSkins,
+            "knifeSkins": knifeSkins
+        }
+        return weaponSkinsList
+
 
     # Gets schema overview
     @staticmethod
@@ -1313,9 +1415,3 @@ def getAllSchemaItems(apiKey):
         result = WebRequest('GET', 'GetSchemaItems', 'v0001', input)
         items = items + result["result"]["items"]
     return items
-
-
-def testSKU(sku):
-    if bool(re.match(
-        "^(\d+);([0-9]|[1][0-5])(;((uncraftable)|(untrad(e)?able)|(australium)|(festive)|(strange)|((u|pk|td-|c|od-|oq-|p)\d+)|(w[1-5])|(kt-[1-3])|(n((100)|[1-9]\d?))))*?$", sku)):
-        return True
